# Lib CoVE

[![PyPI version](https://img.shields.io/pypi/v/libcove.svg)](https://pypi.org/project/libcove/)

This library contains code that can be reused by standard-specific tooling for data review and validation.

## Used by

* [lib-cove-web](https://github.com/OpenDataServices/lib-cove-web/): Common django components for instantiating CoVE web applications
* [lib-cove-bods](http://github.com/openownership/lib-cove-bods/): Beneficial Ownership Data Standard data review tool
* [lib-cove-ocds](https://github.com/open-contracting/lib-cove-ocds): Open Contracting Data Standard data review tool

## PyPi

This [project is published on PyPi](https://pypi.org/project/libcove/).

When creating a release version, please make sure to publish there too.

    python setup.py sdist upload


